@@ -149,7 +149,7 @@
 #'    \item{immobThreshold}{Returns the value from the \code{immobThreshold}
 #'    argument.}
 #'    \item{dateTime}{Timepoint at which polygons were observed.}
-#'    \item{dt}{The the time between reported xy coordinates in row i to row 
+#'    \item{dt}{The time between reported xy coordinates in row i to row 
 #'    i + 1 in each individuals' movement path.}
 #'    
 #'    If MidPoints or CenterPoints == TRUE, additional columns will be appended
@@ -431,7 +431,13 @@ referencePoint2Polygon <-function(x = NULL, id = NULL, dateTime = NULL, point.x
         }
       }
       
-      x<-x[order(x$id, x$dateTime),] #data tables should already be ordered like this, but because this function assumes this ordering scheme, I wanted to ensure it was so.
+      #in case this wasn't already done, we order by date and second. Note that we must order it in this round-about way (using the date and daySecond vectors) to prevent ordering errors that sometimes occurs with dateTime data. It takes a bit longer (especially with larger data sets), but that's the price of accuracy
+      daySecondVec = lubridate::hour(x$dateTime) * 3600 + lubridate::minute(x$dateTime) * 60 + lubridate::second(x$dateTime) #This calculates a day-second
+      lub.dates = lubridate::date(x$dateTime)
+      x<-x[order(x$id, lub.dates, daySecondVec),] #order x 
+      
+      rm(list = c("daySecondVec", "lub.dates")) #remove these objects because they are no longer needed.
+      
       rownames(x)<-seq(1,nrow(x),1)
       
       data.dates<-lubridate::date(x$dateTime) #now we can start concattenating the data by subsetting it into smaller lists
@@ -715,7 +721,13 @@ referencePoint2Polygon <-function(x = NULL, id = NULL, dateTime = NULL, point.x
       }
     }
     
-    x<-x[order(x$id, x$dateTime),] #data tables should already be ordered like this, but because this function assumes this ordering scheme, I wanted to ensure it was so.
+    #in case this wasn't already done, we order by date and second. Note that we must order it in this round-about way (using the date and daySecond vectors) to prevent ordering errors that sometimes occurs with dateTime data. It takes a bit longer (especially with larger data sets), but that's the price of accuracy
+    daySecondVec = lubridate::hour(x$dateTime) * 3600 + lubridate::minute(x$dateTime) * 60 + lubridate::second(x$dateTime) #This calculates a day-second
+    lub.dates = lubridate::date(x$dateTime)
+    x<-x[order(x$id, lub.dates, daySecondVec),] #order x 
+    
+    rm(list = c("daySecondVec", "lub.dates")) #remove these objects because they are no longer needed.
+    
     rownames(x)<-seq(1,nrow(x),1)
     
     data.dates<-lubridate::date(x$dateTime) #now we can start concattenating the data by subsetting it into smaller lists
